import React from "react";
import Placeholder from "@/assets/placeholder.svg?react";

import {
	Dialog,
	DialogContent,
	DialogHeader,
	DialogTitle,
	DialogFooter
} from "@/components/ui/dialog";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { Label } from "@/components/ui/label";
import { Textarea } from "@/components/ui/textarea";
import { Separator } from "@/components/ui/separator";
import { UseFormReturn } from "react-hook-form";
import { ProductForm } from "../hooks/use-product-form";

interface ProductDialogProps {
	open: boolean;
	onOpenChange: (open: boolean) => void;
	form: UseFormReturn<ProductForm>;
	onSubmit: (e?: React.BaseSyntheticEvent) => void;
	onDelete?: () => void;
	onImageUpload: (e: React.ChangeEvent<HTMLInputElement>) => void;
	submitLabel: string;
	imagePreview?: string;
	showDeleteButton?: boolean;
}

export default function ProductDialog({
	open,
	onOpenChange,
	form,
	onSubmit,
	onDelete,
	onImageUpload,
	submitLabel,
	imagePreview,
	showDeleteButton = false
}: ProductDialogProps) {
	return (
		<Dialog open={open} onOpenChange={onOpenChange}>
			<DialogContent className="sm:max-w-2xl">
				<DialogHeader>
					<DialogTitle className="text-2xl font-semibold">
						{submitLabel} Product
					</DialogTitle>
				</DialogHeader>

				<form onSubmit={onSubmit} className="space-y-6">
					{/* Main fields grid */}
					<div className="grid grid-cols-1 gap-6 sm:grid-cols-2">
						{/* Name field */}
						<div className="flex flex-col justify-between">
							<Label htmlFor="name" className="mb-1">
								Product Name
							</Label>
							<Input
								id="name"
								{...form.register("name")}
								placeholder="Enter product name"
							/>
							{form.formState.errors.name && (
								<p className="text-sm text-red-500">
									{form.formState.errors.name.message}
								</p>
							)}

							<div className="flex flex-col">
								<Label htmlFor="price" className="mb-1">
									Price
								</Label>
								<Input
									id="price"
									type="number"
									{...form.register("price", { valueAsNumber: true })}
									placeholder="0.00"
								/>
							</div>

							<div className="flex flex-col">
								<Label htmlFor="stock_quantity" className="mb-1">
									Stock
								</Label>
								<Input
									id="stock_quantity"
									type="number"
									{...form.register("stock_quantity", { valueAsNumber: true })}
									placeholder="0"
								/>
							</div>
						</div>

						{/* Image upload & preview */}
						<div className="flex flex-col items-center">
							<Label htmlFor="image">Image</Label>
							{imagePreview ? (
								<img
									src={imagePreview}
									alt="Preview"
									className="mb-2 h-48 w-48 rounded-lg border object-cover"
								/>
							) : (
								<Placeholder className="h-48 w-48 fill-gray-100 dark:fill-slate-900 text-slate-900 dark:text-zinc-500" />

							)}
							<p className="text-xs text-muted-foreground select-none">
								JPG or PNG only. Max size: 2MB.
							</p>
							<Input
								id="image"
								type="file"
								accept="image/png, image/jpeg"
								onChange={onImageUpload}
								className="pt-1"
							/>
						</div>

						{/* Description spanning full width */}
						<div className="sm:col-span-2">
							<Label htmlFor="description">Description</Label>
							<Textarea
								id="description"
								{...form.register("description")}
								placeholder="Short product description"
								rows={4}
							/>
							{form.formState.errors.description && (
								<p className="text-sm text-red-500">
									{form.formState.errors.description.message}
								</p>
							)}
						</div>
					</div>

					<Separator />

					{/* Action buttons */}
					<DialogFooter className="flex justify-end space-x-3">
						{showDeleteButton && onDelete && (
							<Button variant="destructive" type="button" onClick={onDelete}>
								Delete
							</Button>
						)}
						<Button type="submit">{submitLabel}</Button>
					</DialogFooter>
				</form>
			</DialogContent>
		</Dialog>
	);
}
